Structs
- VVDeserializer
- A struct that deserializes valuable values from the human-readable encoding.
- VVSerializer
- A structure that serializes valuable values in the human-readable encoding.
Enums
- Decode
Error - Everything that can go wrong during deserialization of a valuable value from the human-readable encoding.
- Encode
Error - Everything that can go wrong during serialization of a valuable value into the human-readable encoding.
Functions
- to_vec
- Write human-readable encoding into a Vec.